@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/home/ben/software/install/bin/perl
 use warnings;
 use strict;
 use utf8;
@@ -11,7 +11,6 @@ package Monkey::Shines::Bool;
 sub true { my $monkey = 1; return bless \$monkey; }
 sub false { my $monkey = 0; return bless \$monkey; }
 1;
-package main;
 my $monkeys = {
     CuriousGeorge => Monkey::Shines->new (),
     KingKong => Monkey::Shines::Bool->true (),
